@@ -697,10 +697,10 @@ class CreatePurchase(Wizard):
         for tax in request.product.supplier_taxes_used:
             if request.party and request.party.supplier_tax_rule:
                 pattern = self._get_tax_rule_pattern(request)
-                tax_id = tax_rule_obj.apply(request.party.supplier_tax_rule, 
+                tax_ids = tax_rule_obj.apply(request.party.supplier_tax_rule,
                         tax, pattern)
-                if tax_id:
-                    taxes.append(tax_id)
+                if tax_ids:
+                    taxes.extend(tax_ids)
                 continue
             taxes.append(tax.id)
         line['taxes'] = [('add', taxes)]
